; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below. 
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1

;---|AI Commands|-----------------------------------------------------------
[Command]
name = "AI1"
command = D,D,D,F,F,F,a+b+c+x+y+z
time = 1

[Command]
name = "AI2"
command = D,D,D,F,F,U,a+b+c+x+y+z
time = 1

[Command]
name = "AI3"
command = D,D,D,F,F,UF,a+b+c+x+y+z
time = 1

[Command]
name = "AI4"
command = D,D,D,F,F,D,a+b+c+x+y+z
time = 1

[Command]
name = "AI5"
command = D,D,D,F,F,DF,a+b+c+x+y+z
time = 1

[Command]
name = "AI6"
command = D,D,D,F,F,B,a+b+c+x+y+z
time = 1

[Command]
name = "AI7"
command = D,D,D,F,F,DB,a+b+c+x+y+z
time = 1

[Command]
name = "AI8"
command = D,D,D,F,F,UB,a+b+c+x+y+z
time = 1

[Command]
name = "AI9"
command = D,D,D,F,U,F,a+b+c+x+y+z
time = 1

[Command]
name = "AI10"
command = D,D,D,F,UF,F,a+b+c+x+y+z
time = 1

[Command]
name = "AI11"
command = D,D,D,F,DF,F,a+b+c+x+y+z
time = 1

[Command]
name = "AI12"
command = D,D,D,F,D,F,a+b+c+x+y+z
time = 1

[Command]
name = "AI13"
command = D,D,D,F,DB,F,a+b+c+x+y+z
time = 1

[Command]
name = "AI14"
command = D,D,D,F,B,F,a+b+c+x+y+z
time = 1

[Command]
name = "AI15"
command = D,D,D,F,UB,F,a+b+c+x+y+z
time = 1

[Command]
name = "AI16"
command = D,D,D,F,F,F,a+b+c+x+y,z
time = 1

[Command]
name = "AI17"
command = D,D,D,F,F,F,a+b+c+x,y,z
time = 1

[Command]
name = "AI18"
command = D,D,D,F,F,F,a+b+c,x,y,z
time = 1

[Command]
name = "AI19"
command = D,D,D,F,F,F,a+b,c,x,y,z
time = 1

[Command]
name = "AI20"
command = D,D,D,F,F,F,a,b,c,x,y,z
time = 1

[Command]
name = "AI21"
command = D,D,D,F,F,F,a+b+c,x+y+z
time = 1

[Command]
name = "AI22"
command = D,D,D,F,F,U,a+b,c+x+y+z
time = 1

[Command]
name = "AI23"
command = D,D,D,F,F,UF,a,b+c+x+y+z
time = 1

[Command]
name = "AI24"
command = D,D,D,F,F,U,a+b,c+x+y+z
time = 1

[Command]
name = "AI25"
command = D,D,D,F,F,DF,a,b,c+x+y+z
time = 1

[Command]
name = "AI26"
command = D,D,D,F,F,B,a+b,c+x,y+z
time = 1

[Command]
name = "AI27"
command = D,D,D,F,F,DB,a,b+c+x,y+z
time = 1

[Command]
name = "AI28"
command = D,D,D,F,F,UB,a,b+c+x+y,z
time = 1

[Command]
name = "AI29"
command = DF,D,D,F,U,F,a+b+c+x+y+z
time = 1

[Command]
name = "AI30"
command = B,D,D,F,UF,F,a+b+c+x+y+z
time = 1

[Command]
name = "AI31"
command = B,B,BD,F,DF,F,a+b+c+x+y+z
time = 1

[Command]
name = "AI32"
command = D,F,F,F,D,F,a+b+c+x+y+z
time = 1

[Command]
name = "AI33"
command = DF,D,DF,UF,DB,F,a+b+c+x+y+z
time = 1

[Command]
name = "AI34"
command = D,D,D,F,DB,DF,a+b+c+x+y+z
time = 1

[Command]
name = "AI35"
command = D,D,UF,DF,UB,UF,a+b+c+x+y+z
time = 1

[Command]
name = "AI36"
command = D,DF,DF,DF,DF,F,a+b+c+x+y,z
time = 1

[Command]
name = "AI37"
command = D,D,DB,UF,DF,UF,a+b+c+x,y,z
time = 1

[Command]
name = "AI38"
command = F,U,F,F,F,F,a,b+c,x,y,z
time = 1

[Command]
name = "AI39"
command = DF,UF,D,DF,U,F,a+b,c+x,y,z
time = 1

[Command]
name = "AI40"
command = D,D,D,D,F,D,a+b,c,x,y+z
time = 1


;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;
;-----------
;DEADLY RAVE STUFF
[Command]
name = "~a"
command = a
time = 15

[Command]
name = "~b"
command = b
time = 15

[Command]
name = "~c"
command = c
time = 15

[Command]
name = "~x"
command = x
time = 15

[Command]
name = "~y"
command = y
time = 15

[Command]
name = "~z"
command = z
time = 15
;-------
[Command]
name = "REPPUUZAN"
command = ~5$DB, $F, a
time = 30

[Command]
name = "REPPUUZAN"
command = ~5$DB, $F, b
time = 30

[Command]
name = "360"
command = ~F, D, B, U, $F, x
time = 40

[Command]
name = "360"
command = ~D, B, U, F, $D, x
time = 40

[Command]
name = "360"
command = ~B, D, F, U, $B, x
time = 40

[Command]
name = "360"
command = ~D, F, U, B, $D, x
time = 40

[Command]
name = "360"
command = ~B, U, F, D, $B, x
time = 40

[Command]
name = "360"
command = ~F, U, B, D, $F, x
time = 40

[Command]
name = "360"
command = ~U, F, D, B, $U, x
time = 40

[Command]
name = "360"
command = ~U, B, D, F, $U, x
time = 40

[Command]
name = "360"
command = ~F, D, B, U, $F, y
time = 40

[Command]
name = "360"
command = ~D, B, U, F, $D, y
time = 40

[Command]
name = "360"
command = ~B, D, F, U, $B, y
time = 40

[Command]
name = "360"
command = ~D, F, U, B, $D, y
time = 40

[Command]
name = "360"
command = ~B, U, F, D, $B, y
time = 40

[Command]
name = "360"
command = ~F, U, B, D, $F, y
time = 40

[Command]
name = "360"
command = ~U, F, D, B, $U, y
time = 40

[Command]
name = "360"
command = ~U, B, D, F, $U, y
time = 40

[Command]
name = "PRETZ_xy"
command = ~DB, F, $D, B, DF, x+y
time = 45

[Command]
name = "PRETZ_xy"
command = ~DB, F, $D, B, DF, z
time = 45

[Command]
name = "PRETZ_ab"
command = ~DB, F, $D, B, DF, a+b
time = 45

[Command]
name = "PRETZ_x"
command = ~DB, F, $D, B, DF, x
time = 45

[Command]
name = "PRETZ_y"
command = ~DB, F, $D, B, DF, y
time = 45

[Command]
name = "FHCF_z"
command = ~F, B, D, F, z
time = 40

[Command]
name = "FHCF_z"
command = ~F, B, D, F, a+b
time = 40

[Command]
name = "2HCB_x"
command = ~F, $D, B,F, $D, B, x
time = 40

[Command]
name = "2HCB_y"
command = ~F, $D, B,F, $D, B, y
time = 40

[Command]
name = "HCBF_ab"
command = ~F, D, B, F, a+b
time = 35

[Command]
name = "HCBF_a"
command = ~F, D, B, F, a
time = 35

[Command]
name = "HCBF_b"
command = ~F, D, B, F, b
time = 35

[Command]
name = "HCBF_x"
command = ~F, D, B, F, x
time = 35

[Command]
name = "HCBF_y"
command = ~F, D, B, F, y
time = 35

[Command]
name = "HCBF_z"
command = ~F, D, B, F, z
time = 35

[Command]
name = "QCBF_by"
command = ~D, B, F, b+y
time = 35

[Command]
name = "QCBF_z"
command = ~D, B, F, z
time = 35

[Command]
name = "QCBHCF_xy"
command = ~D, B, D, F, x+y
time = 30

[Command]
name = "QCBHCF_x"
command = ~D, B, D, F, x
time = 30

[Command]
name = "QCBHCF_y"
command = ~D, B, D, F, y
time = 30

[Command]
name = "2QCB_z"
command = ~D, DB, B, D, DB, z
time = 30

[Command]
name = "2QCF_ab"
command = ~D, DF, F, D, DF, a+b
time = 30

[Command]
name = "2QCF_a"
command = ~D, DF, F, D, DF, a
time = 30

[Command]
name = "2QCF_b"
command = ~D, DF, F, D, DF, b
time = 30

[Command]
name = "2QCF_xy"
command = ~D, DF, F, D, DF, x+y
time = 30

[Command]
name = "2QCF_xy"
command = ~D, DF, F, D, DF, z
time = 30

[Command]
name = "2QCF_x"
command = ~D, DF, F, D, DF, x
time = 30

[Command]
name = "2QCF_y"
command = ~D, DF, F, D, DF, y
time = 30

;-| Special Motions |------------------------------------------------------
[Command]
name = "HCFB_x"
command = ~B, D, F, B, x
time = 25

[Command]
name = "HCFB_y"
command = ~B, D, F, B, y
time = 25

[Command]
name = "HCBF_x"
command = ~F, D, B, F, x
time = 25

[Command]
name = "HCBF_y"
command = ~F, D, B, F, y
time = 25

[Command]
name = "RDP_x"
command = ~B, D, DB, x
time = 20

[Command]
name = "RDP_y"
command = ~B, D, DB, y
time = 20

[Command]
name = "DP_x"
command = ~F, D, DF, x
time = 20

[Command]
name = "DP_y"
command = ~F, D, DF, y
time = 20

[Command]
name = "HCF_a"
command = ~B, D, F, a
time = 20

[Command]
name = "HCF_b"
command = ~B, D, F, b
time = 20

[Command]
name = "HCF_x"
command = ~B, D, F, x
time = 20

[Command]
name = "HCF_y"
command = ~B, D, F, y
time = 20

[Command]
name = "HCB_a"
command = ~F, D, B, a
time = 20

[Command]
name = "HCB_b"
command = ~F, D, B, b
time = 20

[Command]
name = "HCB_x"
command = ~F, D, B, x
time = 20

[Command]
name = "HCB_y"
command = ~F, D, B, y
time = 20

[Command]
name = "QCF_a"
command = ~D, DF, F, a
time = 15

[Command]
name = "QCF_b"
command = ~D, DF, F, b
time = 15

[Command]
name = "QCF_x"
command = ~D, DF, F, x
time = 15

[Command]
name = "QCF_y"
command = ~D, DF, F, y
time = 15

[Command]
name = "QCB_yb"
command = ~D, DB, B, y+b
time = 25

[Command]
name = "QCB_z"
command = ~D, DB, B, z
time = 25

[Command]
name = "QCB_a"
command = ~D, DB, B, a
time = 15

[Command]
name = "QCB_b"
command = ~D, DB, B, b
time = 15

[Command]
name = "QCB_x"
command = ~D, DB, B, x
time = 15

[Command]
name = "QCB_y"
command = ~D, DB, B, y
time = 15

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "PChargeA"
command = /a
time = 1

[Command]
name = "PChargeY"
command = /y
time = 1

[Command]
name = "Blowback"
command = b+y
time = 1

[Command]
name = "Roll/Dodge"
command = a+x
time = 1

[Command]
name = "ChargedDU"
command = ~13$D, $U
time = 1

[Command]
name = "hijump"
command = ~$D, $U
time = 8

[Command]
name = "recovery";Required (do not remove)
command = a+x
time = 1

[Command]
name = "recovery";Required (do not remove)
command = c
time = 1


;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdc"
command = /$c
time = 1

[Command]
name = "holdb"
command = /$b
time = 1

[Command]
name = "holda"
command = /$a
time = 1

[Command]
name = "holdz"
command = /$z
time = 1

[Command]
name = "holdy"
command = /$y
time = 1

[Command]
name = "holdx"
command = /$x
time = 1

[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact = 1
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]
;===========================================================================
;Supers
;---------------------------------------------------------------------------
;Raging Dead End LDM
[State -1, Raging Dead End LDM]
type = ChangeState
value = 4400
triggerall = var(5)=2&&var(28)=0
triggerall = var(59) != 1
triggerall = command = "FHCF_z"
triggerall = power >= 3000
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >0) || stateno = 101
trigger2 = stateno = 200 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger6 = stateno = 241 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger7 = stateno = 400 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(3) > 0 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger10 = stateno = 440 && animelemtime(4) > 0 && animelemtime(5) < 0 ;&& !movecontact
trigger11 = stateno = 980 && animelemtime(5) > 0 && animelemtime(6) < 0
trigger12 = stateno = 800 && movecontact = 1
trigger13 = stateno = 1206 && numtarget(1206) && statetype = S && movecontact
trigger14 = stateno = 3101 && time > 110 && time < 140
trigger15 = stateno = 2205 && statetype = S && movecontact
trigger16 = stateno = 995 && movecontact = 1
;---------------------------------------------------------------------------
;Thunder Break LDM
[State -1, Thunder Break LDM]
type = ChangeState
value = 3300
triggerall = var(5)=1
triggerall = var(59) != 1
triggerall = command = "PRETZ_ab"
triggerall = power >= 3000
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >0) || stateno = 101
trigger2 = stateno = 200 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger6 = stateno = 241 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger7 = stateno = 400 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(3) > 0 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger10 = stateno = 440 && animelemtime(4) > 0 && animelemtime(5) < 0 ;&& !movecontact
trigger11 = stateno = 980 && animelemtime(5) > 0 && animelemtime(6) < 0
trigger12 = stateno = 800 && movecontact = 1
trigger13 = stateno = 1206 && numtarget(1206) && statetype = S && movecontact
trigger14 = stateno = 3101 && time > 110 && time < 140
;---------------------------------------------------------------------------
;Raging Storm SDM
[State -1, Raging Storm SDM]
type = ChangeState
value = 3010
triggerall = var(5)=1
triggerall = var(59) != 1
triggerall = command = "PRETZ_xy"
triggerall = power >= 2000
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >0) || stateno = 101
trigger2 = stateno = 200 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger6 = stateno = 241 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger7 = stateno = 400 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(3) > 0 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger10 = stateno = 440 && animelemtime(4) > 0 && animelemtime(5) < 0 ;&& !movecontact
trigger11 = stateno = 980 && animelemtime(5) > 0 && animelemtime(6) < 0
trigger12 = stateno = 800 && movecontact = 1
trigger13 = stateno = 1206 && numtarget(1206) && statetype = S && movecontact
trigger14 = stateno = 2205 && statetype = S && movecontact
trigger15 = stateno = 4104
;---------------------------------------------------------------------------
;Nightmare Raging Storm DM
[State -1, Nightmare Raging Storm DM]
type = ChangeState
value = 4000
triggerall = var(5)=2
triggerall = var(59) != 1
triggerall = command = "PRETZ_x" || command = "PRETZ_y"
triggerall = power >= 1000
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >0) || stateno = 101
trigger2 = stateno = 200 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger6 = stateno = 241 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger7 = stateno = 400 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(3) > 0 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger10 = stateno = 440 && animelemtime(4) > 0 && animelemtime(5) < 0 ;&& !movecontact
trigger11 = stateno = 980 && animelemtime(5) > 0 && animelemtime(6) < 0
trigger12 = stateno = 800 && movecontact = 1
trigger13 = stateno = 1206 && numtarget(1206) && statetype = S && movecontact
trigger14 = stateno = 2205 && statetype = S && movecontact
trigger15 = stateno = 995 && movecontact = 1
;---------------------------------------------------------------------------
;Raging Storm DM
[State -1, Raging Storm DM]
type = ChangeState
value = 3000
triggerall = var(5)=1
triggerall = var(59) != 1
triggerall = command = "PRETZ_x" || command = "PRETZ_y"
triggerall = power >= 1000
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >0) || stateno = 101
trigger2 = stateno = 200 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger6 = stateno = 241 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger7 = stateno = 400 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(3) > 0 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger10 = stateno = 440 && animelemtime(4) > 0 && animelemtime(5) < 0 ;&& !movecontact
trigger11 = stateno = 980 && animelemtime(5) > 0 && animelemtime(6) < 0
trigger12 = stateno = 800 && movecontact = 1
trigger13 = stateno = 1206 && numtarget(1206) && statetype = S && movecontact
trigger14 = stateno = 2205 && statetype = S && movecontact
;---------------------------------------------------------------------------
;Rashoumon DM
[State -1, Rashoumon DM]
type = ChangeState
value = 3100
triggerall = var(5)=1
triggerall = var(59) != 1
triggerall = command = "2HCB_x" || command = "2HCB_y"
triggerall = power >= 1000
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >0) || stateno = 101
trigger2 = stateno = 200 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger6 = stateno = 241 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger7 = stateno = 400 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(3) > 0 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger10 = stateno = 440 && animelemtime(4) > 0 && animelemtime(5) < 0 ;&& !movecontact
trigger11 = stateno = 980 && animelemtime(5) > 0 && animelemtime(6) < 0
trigger12 = stateno = 800 && movecontact = 1
trigger13 = stateno = 1206 && numtarget(1206) && statetype = S && movecontact
trigger14 = stateno = 2205 && statetype = S && movecontact
;---------------------------------------------------------------------------
;MAX Raging Storm SDM
[State -1, MAX Raging Storm SDM]
type = ChangeState
value = 4200
triggerall = var(5)=2
triggerall = var(59) != 1
triggerall = command = "HCBF_ab" || command = "HCBF_z"
triggerall = power >= 2000
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >0) || stateno = 101
trigger2 = stateno = 200 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger6 = stateno = 241 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger7 = stateno = 400 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(3) > 0 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger10 = stateno = 440 && animelemtime(4) > 0 && animelemtime(5) < 0 ;&& !movecontact
trigger11 = stateno = 980 && animelemtime(5) > 0 && animelemtime(6) < 0
trigger12 = stateno = 800 && movecontact = 1
trigger13 = stateno = 1206 && numtarget(1206) && statetype = S && movecontact
trigger14 = stateno = 2205 && statetype = S && movecontact
trigger15 = 995 && movecontact = 1
trigger16 = stateno = 4104
;---------------------------------------------------------------------------
;Deadly Rave SDM
[State -1, Deadly Rave SDM]
type = ChangeState
value = 3200
triggerall = var(5)=1
triggerall = var(59) != 1
triggerall = command = "HCBF_ab" || command = "HCBF_z"
triggerall = power >= 2000
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >0) || stateno = 101
trigger2 = stateno = 200 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger6 = stateno = 241 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger7 = stateno = 400 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(3) > 0 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger10 = stateno = 440 && animelemtime(4) > 0 && animelemtime(5) < 0 ;&& !movecontact
trigger11 = stateno = 980 && animelemtime(5) > 0 && animelemtime(6) < 0
trigger12 = stateno = 800 && movecontact = 1
trigger13 = stateno = 1206 && numtarget(1206) && statetype = S && movecontact
trigger14 = stateno = 2205 && statetype = S && movecontact
trigger15 = stateno = 4104
;---------------------------------------------------------------------------
;Nightmare Deadly Rave DM
[State -1, Nightmare Deadly Rave DM]
type = ChangeState
value = 4100
;triggerall = var(5)=2
triggerall = var(59) != 1
triggerall = command = "HCBF_a" || command = "HCBF_b"
triggerall = power >= 1000
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >0) || stateno = 101
trigger2 = stateno = 200 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger6 = stateno = 241 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger7 = stateno = 400 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(3) > 0 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger10 = stateno = 440 && animelemtime(4) > 0 && animelemtime(5) < 0 ;&& !movecontact
trigger11 = stateno = 980 && animelemtime(5) > 0 && animelemtime(6) < 0
trigger12 = stateno = 800 && movecontact = 1
trigger13 = stateno = 1206 && numtarget(1206) && statetype = S && movecontact
trigger14 = stateno = 2205 && statetype = S && movecontact
trigger15 = stateno = 995 && movecontact = 1
;---------------------------------------------------------------------------
;Ashura Shippuuken SDM
[State -1, Ashura Shippuuken SDM]
type = ChangeState
value = 4300
triggerall = var(5)=2
triggerall = var(59) != 1
triggerall = command = "2QCF_xy"
triggerall = power >= 2000
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >0) || stateno = 101
trigger2 = stateno = 200 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger6 = stateno = 241 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger7 = stateno = 400 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(3) > 0 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger10 = stateno = 440 && animelemtime(4) > 0 && animelemtime(5) < 0 ;&& !movecontact
trigger11 = stateno = 980 && animelemtime(5) > 0 && animelemtime(6) < 0
trigger12 = stateno = 800 && movecontact = 1
trigger13 = stateno = 1206 && numtarget(1206) && statetype = S && movecontact
trigger14 = stateno = 2205 && statetype = S && movecontact
trigger15 = stateno = 995 && movecontact = 1
trigger16 = stateno = 4104
;---------------------------------------------------------------------------
;Specials
;---------------------------------------------------------------------------
;---------------------------------------------------------------------------
;N. Double Shippuuken
[State -1, N. Double Shippuuken]
type = ChangeState
value = 2150
triggerall = var(5) = 2
triggerall = var(59) != 1
triggerall = ifelse((p2bodydist x > 0),command="QCB_y",command="QCF_y")
trigger1 = statetype = A && ctrl || stateno = 105
trigger2 = stateno = 600 && movecontact
trigger3 = stateno = 610 && movecontact
trigger4 = stateno = 815 && movecontact
trigger5 = stateno = 990 && movecontact
;---------------------------------------------------------------------------
;N. Shippuuken
[State -1, N. Shippuuken]
type = ChangeState
value = 2100
triggerall = var(5) = 2
triggerall = var(59) != 1
triggerall = ifelse((p2bodydist x > 0),command="QCB_x",command="QCF_x")
trigger1 = statetype = A && ctrl || stateno = 105
trigger2 = stateno = 600 && movecontact
trigger3 = stateno = 610 && anim = 610 && movecontact
trigger4 = stateno = 815 && movecontact
trigger5 = stateno = 990 && movecontact
;---------------------------------------------------------------------------
;N. Double Reppuuken
[State -1, N. Reppuuken]
type = ChangeState
value = 2005
triggerall = var(5) = 2
triggerall = var(59) != 1
triggerall = ifelse((Anim!=[5,6]),command="QCF_y",command="QCB_y") && !numprojid(2000) && !numprojid(2006) && !numprojid(2007)
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >0) || stateno = 101
trigger2 = stateno = 200 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger6 = stateno = 241 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger7 = stateno = 400 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(3) > 0 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger10 = stateno = 440 && animelemtime(4) > 0 && animelemtime(5) < 0 ;&& !movecontact
trigger11 = stateno = 800 && animelemtime(5) > 0 && animelemtime(6) < 0
trigger12 = stateno = 980 && animelemtime(5) > 0 && animelemtime(6) < 0
trigger13 = var(5)=2 && stateno = 995 && movecontact = 1

;N. Reppuuken
[State -1, N. Reppuuken]
type = ChangeState
value = 2000
triggerall = var(5) = 2
triggerall = var(59) != 1
triggerall = ifelse((Anim!=[5,6]),command="QCF_x",command="QCB_x") && !numprojid(2000) && !numprojid(2006) && !numprojid(2007)
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >0) || stateno = 101
trigger2 = stateno = 200 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger6 = stateno = 241 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger7 = stateno = 400 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(3) > 0 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger10 = stateno = 440 && animelemtime(4) > 0 && animelemtime(5) < 0 ;&& !movecontact
trigger11 = stateno = 800 && animelemtime(5) > 0 && animelemtime(6) < 0
trigger12 = stateno = 980 && animelemtime(5) > 0 && animelemtime(6) < 0
trigger13 = var(5)=2 && stateno = 995 && movecontact = 1
;---------------------------------------------------------------------------
;Nightmare Raimei Gou Hazaki Nage
[State -1, Nightmare Raimei Gou Hazaki Nage]
type = ChangeState
value = 1550
triggerall = var(5) = 2
triggerall = var(59) != 1
triggerall = p2stateno = 5110 || p2stateno = 5100 || p2stateno = 5101
triggerall = ifelse((Anim!=[5,6]),command = "holddown" && command = "holdfwd" && command = "y",command = "holddown" && command = "holdback" && command = "y")
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >0) || stateno = 101
trigger2 = stateno = 200 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger6 = stateno = 241 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger7 = stateno = 400 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(3) > 0 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger10 = stateno = 440 && animelemtime(4) > 0 && animelemtime(5) < 0 ;&& !movecontact
trigger11 = stateno = 800 && animelemtime(5) > 0 && animelemtime(6) < 0
trigger12 = stateno = 980 && animelemtime(5) > 0 && animelemtime(6) < 0
trigger13 = var(5)=2 && stateno = 995 && movecontact = 1
;---------------------------------------------------------------------------
;Nightmare Chuudan Atemi Nage
[State -1, Nightmare Chuudan Atemi Nage]
type = ChangeState
value = 1449
triggerall = var(5) = 2 && var(28)=0
triggerall = var(59) != 1
triggerall = ifelse((Anim!=[5,6]),command="HCB_b",command="HCF_b")
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >0) || stateno = 101
trigger2 = stateno = 200 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger6 = stateno = 241 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger7 = stateno = 400 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(3) > 0 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger10 = stateno = 440 && animelemtime(4) > 0 && animelemtime(5) < 0 ;&& !movecontact
trigger11 = stateno = 800 && animelemtime(5) > 0 && animelemtime(6) < 0
trigger12 = stateno = 980 && animelemtime(5) > 0 && animelemtime(6) < 0
trigger13 = var(5)=2 && stateno = 995 && movecontact = 1
;---------------------------------------------------------------------------
;Raging Dead End Counter Attempt
[State -1, Raging Dead End Counter Attempt]
type = ChangeState
value = 4402
triggerall = var(5) = 2 && var(28)=1
triggerall = var(59) != 1
triggerall = ifelse((Anim!=[5,6]),command="HCB_b",command="HCF_b") || ifelse((Anim!=[5,6]),command="HCF_a",command="HCB_a") || ifelse((Anim!=[5,6]),command="HCB_a",command="HCF_a")
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >0) || stateno = 101
trigger2 = stateno = 200 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger6 = stateno = 241 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger7 = stateno = 400 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(3) > 0 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger10 = stateno = 440 && animelemtime(4) > 0 && animelemtime(5) < 0 ;&& !movecontact
trigger11 = stateno = 800 && animelemtime(5) > 0 && animelemtime(6) < 0
trigger12 = stateno = 980 && animelemtime(5) > 0 && animelemtime(6) < 0
trigger13 = var(5)=2 && stateno = 995 && movecontact = 1
;---------------------------------------------------------------------------
;Normal Geese
;---------------------------------------------------------------------------
;Ura Kumo In
[State -1, Ura Kumo In]
type = ChangeState
value = 1600
triggerall = var(59) != 1
triggerall = ifelse((Anim!=[5,6]),command="HCBF_y",command="HCFB_y")
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >0) || stateno = 101
trigger2 = stateno = 200 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger6 = stateno = 241 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger7 = stateno = 400 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(3) > 0 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger10 = stateno = 440 && animelemtime(4) > 0 && animelemtime(5) < 0 ;&& !movecontact
trigger11 = stateno = 800 && animelemtime(5) > 0 && animelemtime(6) < 0
trigger12 = stateno = 980 && animelemtime(5) > 0 && animelemtime(6) < 0
trigger13 = var(5)=2 && stateno = 995 && movecontact = 1
;---------------------------------------------------------------------------
;Ura Kumo In
[State -1, Ura Kumo In]
type = ChangeState
value = 1600
triggerall = var(59) != 1
triggerall = ifelse((Anim!=[5,6]),command="HCBF_x",command="HCFB_x")
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >0) || stateno = 101
trigger2 = stateno = 200 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger6 = stateno = 241 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger7 = stateno = 400 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(3) > 0 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger10 = stateno = 440 && animelemtime(4) > 0 && animelemtime(5) < 0 ;&& !movecontact
trigger11 = stateno = 800 && animelemtime(5) > 0 && animelemtime(6) < 0
trigger12 = stateno = 980 && animelemtime(5) > 0 && animelemtime(6) < 0
trigger13 = var(5)=2 && stateno = 995 && movecontact = 1
;---------------------------------------------------------------------------
;N. Jaeiken Hard
[State -1, N. Jaeiken Hard]
type = ChangeState
value = 2250
triggerall = var(5) = 2
triggerall = var(59) != 1
triggerall = ifelse((Anim!=[5,6]),command="HCB_y",command="HCF_y")
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >0) || stateno = 101
trigger2 = stateno = 200 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger6 = stateno = 241 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger7 = stateno = 400 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(3) > 0 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger10 = stateno = 440 && animelemtime(4) > 0 && animelemtime(5) < 0 ;&& !movecontact
trigger11 = stateno = 800 && animelemtime(5) > 0 && animelemtime(6) < 0
trigger12 = stateno = 980 && animelemtime(5) > 0 && animelemtime(6) < 0
trigger13 = var(5)=2 && stateno = 995 && movecontact = 1
;---------------------------------------------------------------------------
;N. Jaeiken Weak
[State -1, N. Jaeiken Weak]
type = ChangeState
value = 2200
triggerall = var(5) = 2
triggerall = var(59) != 1
triggerall = ifelse((Anim!=[5,6]),command="HCB_x",command="HCF_x")
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >0) || stateno = 101
trigger2 = stateno = 200 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger6 = stateno = 241 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger7 = stateno = 400 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(3) > 0 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger10 = stateno = 440 && animelemtime(4) > 0 && animelemtime(5) < 0 ;&& !movecontact
trigger11 = stateno = 800 && animelemtime(5) > 0 && animelemtime(6) < 0
trigger12 = stateno = 980 && animelemtime(5) > 0 && animelemtime(6) < 0
trigger13 = var(5)=2 && stateno = 995 && movecontact = 1
;---------------------------------------------------------------------------
;Raimei Gou Hazaki Nage
[State -1, Raimei Gou Hazaki Nage]
type = ChangeState
value = 1500
triggerall = var(5) = 1
triggerall = var(59) != 1
triggerall = p2stateno = 5110 || p2stateno = 5100 || p2stateno = 5101
triggerall = ifelse((Anim!=[5,6]),command = "holddown" && command = "holdfwd" && command = "y",command = "holddown" && command = "holdback" && command = "y")
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >0) || stateno = 101
trigger2 = stateno = 200 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger6 = stateno = 241 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger7 = stateno = 400 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(3) > 0 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger10 = stateno = 440 && animelemtime(4) > 0 && animelemtime(5) < 0 ;&& !movecontact
trigger11 = stateno = 800 && animelemtime(5) > 0 && animelemtime(6) < 0
trigger12 = stateno = 980 && animelemtime(5) > 0 && animelemtime(6) < 0
;---------------------------------------------------------------------------
;Gedan Atemi Uchi
[State -1,  Gedan Atemi Uchi]
type = ChangeState
value = 1415
;triggerall = var(5) = 1
triggerall = var(59) != 1 && var(28)=0
triggerall = ifelse((Anim!=[5,6]),command="HCF_a",command="HCB_a") 
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >0) || stateno = 101
trigger2 = stateno = 200 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger6 = stateno = 241 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger7 = stateno = 400 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(3) > 0 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger10 = stateno = 440 && animelemtime(4) > 0 && animelemtime(5) < 0 ;&& !movecontact
trigger11 = stateno = 800 && animelemtime(5) > 0 && animelemtime(6) < 0
trigger12 = stateno = 980 && animelemtime(5) > 0 && animelemtime(6) < 0
trigger13 = var(5)=2 && stateno = 995 && movecontact = 1
;---------------------------------------------------------------------------
;Chuudan Atemi Nage
[State -1,  Chuudan Atemi Nage]
type = ChangeState
value = 1410
triggerall = var(5) = 1
triggerall = var(59) != 1
triggerall = ifelse((Anim!=[5,6]),command="HCB_b",command="HCF_b") 
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >0) || stateno = 101
trigger2 = stateno = 200 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger6 = stateno = 241 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger7 = stateno = 400 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(3) > 0 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger10 = stateno = 440 && animelemtime(4) > 1 && animelemtime(5) < 0 ;&& !movecontact
trigger11 = stateno = 800 && animelemtime(5) > 0 && animelemtime(6) < 0
trigger12 = stateno = 980 && animelemtime(5) > 0 && animelemtime(6) < 0
;---------------------------------------------------------------------------
;Joudan Atemi Nage
[State -1,  Joudan Atemi Nage]
type = ChangeState
value = 1400
;triggerall = var(5) = 1
triggerall = var(59) != 1
triggerall = ifelse((Anim!=[5,6]),command="HCB_a",command="HCF_a") 
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >0) || stateno = 101
trigger2 = stateno = 200 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger6 = stateno = 241 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger7 = stateno = 400 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(3) > 0 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger10 = stateno = 440 && animelemtime(4) > 0 && animelemtime(5) < 0 ;&& !movecontact
trigger11 = stateno = 800 && animelemtime(5) > 0 && animelemtime(6) < 0
trigger12 = stateno = 980 && animelemtime(5) > 0 && animelemtime(6) < 0
trigger13 = var(5)=2 && stateno = 995 && movecontact = 1
;---------------------------------------------------------------------------
;Hishou Nichirinzan Hard
[State -1, Hishou Nichirinzan]
type = ChangeState
value = 1305
triggerall = var(5) = 1
triggerall = var(59) != 1
triggerall = ifelse((Anim!=[5,6]),command="DP_y",command="RDP_y") 
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >0) || stateno = 101
trigger2 = stateno = 200 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger6 = stateno = 241 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger7 = stateno = 400 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(3) > 0 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger10 = stateno = 440 && animelemtime(4) > 0 && animelemtime(5) < 0 ;&& !movecontact
trigger11 = stateno = 800 && animelemtime(5) > 0 && animelemtime(6) < 0
trigger12 = stateno = 980 && animelemtime(5) > 0 && animelemtime(6) < 0
;---------------------------------------------------------------------------
;Hishou Nichirinzan Weak
[State -1, Hishou Nichirinzan]
type = ChangeState
value = 1300
triggerall = var(5) = 1
triggerall = var(59) != 1
triggerall = ifelse((Anim!=[5,6]),command="DP_x",command="RDP_x") 
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >0) || stateno = 101
trigger2 = stateno = 200 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger6 = stateno = 241 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger7 = stateno = 400 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(3) > 0 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger10 = stateno = 440 && animelemtime(4) > 0 && animelemtime(5) < 0 ;&& !movecontact
trigger11 = stateno = 800 && animelemtime(5) > 0 && animelemtime(6) < 0
trigger12 = stateno = 980 && animelemtime(5) > 0 && animelemtime(6) < 0
;---------------------------------------------------------------------------
;---------------------------------------------------------------------------
;Jaeiken
[State -1, Jaeiken]
type = ChangeState
value = 1205
triggerall = var(5) = 1
triggerall = var(59) != 1
triggerall = ifelse((Anim!=[5,6]),command="HCB_y",command="HCF_y") 
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >0) || stateno = 101
trigger2 = stateno = 200 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger6 = stateno = 241 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger7 = stateno = 400 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(3) > 0 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger10 = stateno = 440 && animelemtime(4) > 0 && animelemtime(5) < 0 ;&& !movecontact
trigger11 = stateno = 800 && animelemtime(5) > 0 && animelemtime(6) < 0
trigger12 = stateno = 980 && animelemtime(5) > 0 && animelemtime(6) < 0
;---------------------------------------------------------------------------
;Jaeiken
[State -1, Jaeiken]
type = ChangeState
value = 1200
triggerall = var(5) = 1
triggerall = var(59) != 1
triggerall = ifelse((Anim!=[5,6]),command="HCB_x",command="HCF_x") 
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >0) || stateno = 101
trigger2 = stateno = 200 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger6 = stateno = 241 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger7 = stateno = 400 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(3) > 0 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger10 = stateno = 440 && animelemtime(4) > 0 && animelemtime(5) < 0 ;&& !movecontact
trigger11 = stateno = 800 && animelemtime(5) > 0 && animelemtime(6) < 0
trigger12 = stateno = 980 && animelemtime(5) > 0 && animelemtime(6) < 0
;---------------------------------------------------------------------------
;Shippuuken
[State -1, Shippuuken]
type = ChangeState
value = 1100
triggerall = var(5) = 1
triggerall = var(59) != 1
triggerall = ifelse((p2bodydist x > 0),command="QCB_y",command="QCF_y") && !numprojid(1100) 
trigger1 = statetype = A && ctrl
trigger2 = stateno = 610 && anim = 610 && movecontact
trigger3 = stateno = 990 && movecontact
;---------------------------------------------------------------------------
;Shippuuken
[State -1, Shippuuken]
type = ChangeState
value = 1100
triggerall = var(5) = 1
triggerall = var(59) != 1
triggerall = ifelse((p2bodydist x > 0),command="QCB_x",command="QCF_x") && !numprojid(1100) 
trigger1 = statetype = A && ctrl
trigger2 = stateno = 610 && anim = 610 && movecontact
trigger3 = stateno = 990 && movecontact
;---------------------------------------------------------------------------
;Double Reppuuken
[State -1, Reppuuken]
type = ChangeState
value = 1005
triggerall = var(5) = 1
triggerall = var(59) != 1
triggerall = ifelse((Anim!=[5,6]),command="QCF_y",command="QCB_y") && !numprojid(1000) && !numprojid(1006) && !numprojid(1007)
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >0) || stateno = 101
trigger2 = stateno = 200 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger6 = stateno = 241 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger7 = stateno = 400 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(3) > 0 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger10 = stateno = 440 && animelemtime(4) > 0 && animelemtime(5) < 0 ;&& !movecontact
trigger11 = stateno = 800 && animelemtime(5) > 0 && animelemtime(6) < 0
trigger12 = stateno = 980 && animelemtime(5) > 0 && animelemtime(6) < 0

;Reppuuken
[State -1, Reppuuken]
type = ChangeState
value = 1000
triggerall = var(5) = 1
triggerall = var(59) != 1
triggerall = ifelse((Anim!=[5,6]),command="QCF_x",command="QCB_x") && !numprojid(1000) && !numprojid(1006) && !numprojid(1007)
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >0) || stateno = 101
trigger2 = stateno = 200 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger6 = stateno = 241 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger7 = stateno = 400 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(3) > 0 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger10 = stateno = 440 && animelemtime(4) > 0 && animelemtime(5) < 0 ;&& !movecontact
trigger11 = stateno = 800 && animelemtime(5) > 0 && animelemtime(6) < 0
trigger12 = stateno = 980 && animelemtime(5) > 0 && animelemtime(6) < 0

;===========================================================================
;---------------------------------------------------------------------------
;Guard Counter Blowback Attack
[State -1, Guard Counter Blowback Attack]
type = ChangeState
value = 995
triggerall = var(59) != 1
triggerall = statetype != A
trigger1 = command = "z" || command = "Blowback"
trigger1 = stateno = 150 || stateno = 151
trigger1 = power >= 1000

;---------------------------------------------------------------------------
;Blowback Attack Air
[State -1, Blowback Attack Air]
type = ChangeState
value = 990
trigger1 = !var(59)
trigger1 = command = "z" || command = "Blowback"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Blowback Attack Ground
[State -1, Blowback Attack Ground]
type = ChangeState
value = 980
trigger1 = !var(59)
trigger1 = command = "z" || command = "Blowback"
trigger1 = statetype = S
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >1) || stateno = 101

;---------------------------------------------------------------------------
;Emergency Counter Attack
[State -1, Emergency Counter Attack]
type = Null
value = 780
trigger1 = !var(59)
trigger1 = command = "z" || command = "Blowback"
trigger1 = stateno = [5000,5022]
trigger1 = enemy, stateno = [200,990]
trigger1 = fvar(5) >= 1000

;--------------------------------------------------------------------------
;Power Charge
[State -1, Power Charge]
type = ChangeState
value = 770
triggerall = var(59) != 1
triggerall = power < 3000
triggerall = (command = "PChargeA" && command = "PChargeY")
trigger1 = statetype != A
trigger1 = ctrl && stateno != 20

;---------------------------------------------------------------------------
;Emergency Evade Backward
[State -1, Emergency Evade Backward]
type = ChangeState
value = 761
triggerall = var(59) != 1
triggerall = command = "holdback"
triggerall = statetype != A
trigger1 = command = "Roll/Dodge" || command = "c"
trigger1 = stateno = 150 || stateno = 151
trigger1 = power >= 1000

;---------------------------------------------------------------------------
;Emergency Evade Forward
[State -1, Emergency Evade Forward]
type = ChangeState
value = 760
triggerall = var(59) != 1
triggerall = command != "holdback"
triggerall = statetype != A
trigger1 = command = "Roll/Dodge" || command = "c"
trigger1 = stateno = 150 || stateno = 151
trigger1 = power>= 1000

;---------------------------------------------------------------------------
;Roll Backward
[State -1, Roll Backward]
type = ChangeState
value = 761
triggerall = var(59) != 1
trigger1 = command = "Roll/Dodge" || command = "c"
trigger1 = command = "holdback" || command = "holddown"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Roll Forward
[State -1, Roll Forward]
type = ChangeState
value = 760
triggerall = var(59) != 1
trigger1 = command = "Roll/Dodge" || command = "c"
trigger1 = command != "holdback"
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >1) || stateno = 101

;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
;ރ_bV
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl


;===========================================================================
;---------------------------------------------------------------------------
;Hien Shikkyaku C.I
[State -1, Hien Shikkyaku C.I]
type = ChangeState
value = 815
triggerall = var(5)=2
triggerall = command != "holddown" && command = "holdfwd" && command = "x"
trigger1 = statetype != A
trigger1 = stateno = 200 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger2 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger3 = stateno = 211 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger4 = stateno = 231 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger5 = stateno = 241 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger6 = stateno = 400 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger7 = stateno = 410 && animelemtime(3) > 0 && animelemtime(5) < 0
trigger8 = stateno = 430 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger9 = stateno = 440 && animelemtime(4) > 0 && animelemtime(5) < 0 ;&& !movecontact
trigger10 = stateno = 980 && animelemtime(5) > 0 && animelemtime(6) < 0
;---------------------------------------------------------------------------
;Hien Shikkyaku
[State -1, Hien Shikkyaku]
type = ChangeState
value = 810
triggerall = var(5)=2
triggerall = command != "holddown" && command = "holdfwd" && command = "x"
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >0) || stateno = 101
trigger1 = statetype != A
;---------------------------------------------------------------------------
;Raikou Mawashi Geri
[State -1, Raikou Mawashi Geri]
type = ChangeState
value = 800
triggerall = command != "holddown" && command = "holdfwd" && command = "a"
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >0) || stateno = 101
trigger1 = statetype != A
trigger2 = stateno = 200 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger6 = stateno = 241 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger7 = stateno = 400 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(3) > 0 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger10 = stateno = 440 && animelemtime(4) > 0 && animelemtime(5) < 0 ;&& !movecontact
trigger11 = stateno = 980 && animelemtime(5) > 0 && animelemtime(6) < 0

;-------------------------------------------------------------------------------
;Grab Attempt
[State -1, Grab Attempt]
type = ChangeState
value = 850
triggerall = var(59) != 1
triggerall = command = "holdfwd" || command = "holdback" && anim = 21
triggerall = command = "y" || command = "b"
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = p2bodydist x < 20
trigger1 = p2movetype != H
trigger1 = p2statetype != A

;---------------------------------------------------------------------------
;Taunt
;
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = var(59) != 1
triggerall = command = "start"
trigger1 = stateno != 195
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >0) || stateno = 101
trigger1 = roundstate = 2

;---------------------------------------------------------------------------
;Stand Light Punch
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = var(59) != 1
triggerall = command = "x"
triggerall = command != "holddown"
triggerall = p2bodydist x > 26
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >0) || stateno = 101
trigger2 = stateno = 201 && time > 5
trigger3 = stateno = 200 && time > 5
trigger4 = stateno = 231 && time > 4
trigger5 = stateno = 400 && time > 5
trigger6 = stateno = 430 && time > 8

;---------------------------------------------------------------------------
;Stand Light Punch C
[State -1, Stand Light Punch C]
type = ChangeState
value = 201
triggerall = var(59) != 1
triggerall = command = "x"
triggerall = command != "holddown"
triggerall = p2bodydist x <= 26
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >0) || stateno = 101
trigger2 = stateno = 201 && time > 5
trigger3 = stateno = 200 && time > 5
trigger4 = stateno = 231 && time > 4
trigger5 = stateno = 400 && time > 5
trigger6 = stateno = 430 && time > 8

;---------------------------------------------------------------------------
;Stand Strong Punch
[State -1, Stand Strong Punch]
type = ChangeState
value = 210
triggerall = var(59) != 1
triggerall = command = "y"
triggerall = command != "holddown"
triggerall = p2bodydist x > 28
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >0) || stateno = 101

;---------------------------------------------------------------------------
;Stand Strong Punch C
[State -1, Stand Strong Punch C]
type = ChangeState
value = 211
triggerall = var(59) != 1
triggerall = command = "y"
triggerall = command != "holddown"
triggerall = p2bodydist x <= 28
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >0) || stateno = 101

;---------------------------------------------------------------------------
;Stand Light Kick
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = var(59) != 1
triggerall = command = "a"
triggerall = command != "holddown"
triggerall = p2bodydist x > 27
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >0) || stateno = 101

;---------------------------------------------------------------------------
;Stand Light Kick C
[State -1, Stand Light Kick C]
type = ChangeState
value = 231
triggerall = var(59) != 1
triggerall = command = "a"
triggerall = command != "holddown"
triggerall = p2bodydist x <= 27
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >0) || stateno = 101
trigger2 = stateno = 201 && time > 5
trigger3 = stateno = 200 && time > 5
trigger4 = stateno = 231 && time > 4
trigger5 = stateno = 400 && time > 5
trigger6 = stateno = 430 && time > 8

;---------------------------------------------------------------------------
;Standing Strong Kick
[State -1, Standing Strong Kick]
type = ChangeState
value = 240
triggerall = var(59) != 1
triggerall = command = "b"
triggerall = command != "holddown"
triggerall = p2bodydist x > 30
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >0) || stateno = 101

;---------------------------------------------------------------------------
;Standing Strong Kick C
[State -1, Standing Strong Kick C]
type = ChangeState
value = 241
triggerall = var(59) != 1
triggerall = command = "b"
triggerall = command != "holddown"
triggerall = p2bodydist x <= 30
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >0) || stateno = 101

;---------------------------------------------------------------------------
;Crouching Light Punch
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = var(59) != 1
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 100 && animelemtime(2) >0) || stateno = 101
trigger3 = stateno = 201 && time > 5
trigger4 = stateno = 200 && time > 5
trigger5 = stateno = 231 && time > 4
trigger6 = stateno = 400 && time > 5
trigger7 = stateno = 430 && time > 8

;---------------------------------------------------------------------------
;Crouching Strong Punch
[State -1, Crouching Strong Punch]
type = ChangeState
value = 410
triggerall = var(59) != 1
triggerall = command = "holddown"
triggerall = command = "y"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 100 && animelemtime(2) >0) || stateno = 101

;---------------------------------------------------------------------------
;Crouching Light Kick
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = var(59) != 1
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 100 && animelemtime(2) >0) || stateno = 101
trigger3 = stateno = 201 && time > 5
trigger4 = stateno = 200 && time > 5
trigger5 = stateno = 231 && time > 4
trigger6 = stateno = 400 && time > 5
trigger7 = stateno = 430 && time > 8

;---------------------------------------------------------------------------
;Crouching Strong Kick
[State -1, Crouching Strong Kick]
type = ChangeState
value = 440
triggerall = var(59) != 1
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 100 && animelemtime(2) >0) || stateno = 101

;---------------------------------------------------------------------------
;Jump Light Punch
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = var(59) != 1
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 610
triggerall = var(59) != 1
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = var(59) != 1
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Jump Strong Kick
[State -1, Jump Strong Kick]
type = ChangeState
value = 640
triggerall = var(59) != 1
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Jump Strong Kick Vel X != 0
[State -1, Jump Strong Kick Vel X!= 0]
type = Null
value = 641
triggerall = var(59) != 1
triggerall = command = "b"
trigger1 = vel x != 0 || stateno = 41
trigger1 = statetype = A
trigger1 = ctrl

;THANKS TO ANJEL FOR ALL THIS
;----|AI|-------------------------------------------------------------------
[State -1, Activate AI]
type = VarSet
triggerall = var(59) != 1
trigger1 = command = "AI1"
trigger2 = command = "AI2"
trigger3 = command = "AI3"
trigger4 = command = "AI4"
trigger5 = command = "AI5"
trigger6 = command = "AI6"
trigger7 = command = "AI7"
trigger8 = command = "AI8"
trigger9 = command = "AI9"
trigger10 = command = "AI10"
trigger11 = command = "AI11"
trigger12 = command = "AI12"
trigger13 = command = "AI13"
trigger14 = command = "AI14"
trigger15 = command = "AI15"
trigger16 = command = "AI16"
trigger17 = command = "AI17"
trigger18 = command = "AI18"
trigger19 = command = "AI19"
trigger20 = command = "AI20"
trigger21 = command = "AI21"
trigger22 = command = "AI22"
trigger23 = command = "AI23"
trigger24 = command = "AI24"
trigger25 = command = "AI25"
trigger26 = command = "AI26"
trigger27 = command = "AI27"
trigger28 = command = "AI28"
trigger29 = command = "AI29"
trigger30 = command = "AI30"
trigger31 = command = "AI31"
trigger32 = command = "AI32"
trigger33 = command = "AI33"
trigger34 = command = "AI34"
trigger35 = command = "AI35"
trigger36 = command = "AI36"
trigger37 = command = "AI37"
trigger38 = command = "AI38"
trigger39 = command = "AI39"
trigger40 = command = "AI40"
var(59) = 1
;----------------------------------------------------------------------------
[State -1, Kill AI]
type = VarSet
triggerall = var(59) = 1
trigger1 = life < 0
trigger2 = winko
trigger3 = loseko
value = 0

;----------------------------------------------------------------------------
;light punch
[State -1, AI Run]
type = ChangeState
triggerall = stateno != [3000,3999]
triggerall = var(59) = 1
triggerall = random <= 60
triggerall = StateType != A
triggerall = Movetype != H
triggerall = P2Life > 0
triggerall = P2bodydist X > 200
trigger1 = ctrl
value = 100
;----------------------------------------------------------------------------
;light punch
[State -1, AI Hop Back]
type = Null
triggerall = stateno != [3000,3999]
triggerall = var(59) = 1
triggerall = random <= 180
triggerall = StateType != A
triggerall = Movetype != H
triggerall = P2Life > 0
triggerall = P2bodydist X < 80
trigger1 = p2stateno = 5120
trigger1 = ctrl
value = 105
;----------------------------------------------------------------------------
;light punch
[State -1, AI light punch]
type = ChangeState
triggerall = stateno != [3000,3999]
triggerall = var(59) = 1
triggerall = random <= 160
triggerall = StateType = S
triggerall = Movetype != H
triggerall = P2Life > 0
triggerall = P2bodydist X <= 30
trigger1 = ctrl && !numtarget(1400)
value = IfElse(p2dist X < 26,201,200)
;----------------------------------------------------------------------------
;heavy punch
[State -1, AI heavy Attack]
type = ChangeState
triggerall = stateno != [3000,3999]
triggerall = var(59) = 1
triggerall = random <= 240
triggerall = StateType = S
triggerall = Movetype != H
triggerall = P2Life > 0
triggerall = P2bodydist X <= 35
trigger1 = ctrl && !numtarget(1400)
value = IfElse(p2dist X < 28,211,210)
;----------------------------------------------------------------------------
;light punch
[State -1, AI light Kick]
type = ChangeState
triggerall = stateno != [3000,3999]
triggerall = var(59) = 1
triggerall = random <= 170
triggerall = StateType = S
triggerall = Movetype != H
triggerall = P2Life > 0
triggerall = P2bodydist X <= 25
trigger1 = ctrl && !numtarget(1400)
value = IfElse(p2dist X < 27,231,230)
;----------------------------------------------------------------------------
;heavy punch
[State -1, AI heavy Kick]
type = ChangeState
triggerall = stateno != [3000,3999]
triggerall = var(59) = 1
triggerall = random <= 280
triggerall = StateType = S
triggerall = Movetype != H
triggerall = P2Life > 0
triggerall = P2bodydist X <= 36
trigger1 = ctrl && !numtarget(1400)
value = IfElse(p2dist X < 30,241,240)
;----------------------------------------------------------------------------
;light punch
[State -1, AI Crouch Attack]
type = ChangeState
triggerall = stateno != [3000,3999]
triggerall = var(59) = 1
triggerall = random <= 300
triggerall = StateType = C
triggerall = Movetype != H
triggerall = P2Life > 0
triggerall = P2bodydist X <= 40
trigger1 = ctrl
value = 410
;----------------------------------------------------------------------------
;light punch
[State -1, AI Air Attack]
type = ChangeState
triggerall = stateno != [3000,3999]
triggerall = var(59) = 1
triggerall = random <= 200
triggerall = StateType = A
triggerall = Movetype != H
triggerall = P2Life > 0
triggerall = P2bodydist X <= 70
trigger1 = ctrl && !numtarget(1400)
value = 640
;----------------------------------------------------------------------------
;medium punch
[State -1, AI guard cancel CD nightmare]
type = ChangeState
triggerall = stateno = [150,151]
triggerall = var(59) = 1 && var(5)=2
triggerall = power >= 1000
triggerall = Movetype != H
triggerall = P2Life > 0
triggerall = P2bodydist X <= 90
trigger1 = (enemynear,hitdefattr=SC,NA,SA,HA)
trigger1 = stateno != 995
value = 995
;----------------------------------------------------------------------------
;light punch
[State -1, AI DIEFOREVER]
type = ChangeState
triggerall = var(5) = 1
triggerall = stateno != [3000,3999]
triggerall = var(59) = 1
triggerall = random <= 400
triggerall = StateType != A
triggerall = Movetype != H
triggerall = P2Life > 0
triggerall = P2bodydist X <= 40
triggerall = enemynear, statetype = L
trigger1 = ctrl
value = 1500
;----------------------------------------------------------------------------
;light punch
[State -1, AI NDIEFOREVER]
type = ChangeState
triggerall = var(5) = 2
triggerall = stateno != [3000,3999]
triggerall = var(59) = 1
triggerall = random <= 400
triggerall = StateType != A
triggerall = Movetype != H
triggerall = P2Life > 0
triggerall = P2bodydist X <= 40
triggerall = enemynear, statetype = L
trigger1 = ctrl
trigger2 = ctrl && numtarget(1400)
value = 1550
;----------------------------------------------------------------------------
;medium punch
[State -1, AI reppuuken]
type = ChangeState
triggerall = stateno != [3000,3999]
triggerall = var(59) = 1
triggerall = var(5) = 1
triggerall = StateType != A
triggerall = Movetype != H
triggerall = P2Life > 0
triggerall = random <= 200 && !numprojid(1000) && !numprojid(1006) && !numprojid(1007)
triggerall = P2bodydist X >= 100
trigger1 = ctrl
trigger2 = stateno = 211 && movecontact = 1
trigger3 = stateno = 241 && movecontact = 1
trigger4 = stateno = 800 && movecontact = 1
value = IfElse(Random < 500,1000,IfElse(Random < 500,1005,1000))
;----------------------------------------------------------------------------
;medium punch
[State -1, AI nreppuuken]
type = ChangeState
triggerall = stateno != [3000,3999]
triggerall = var(59) = 1
triggerall = var(5) = 2
triggerall = StateType != A
triggerall = Movetype != H
triggerall = P2Life > 0
triggerall = random <= 200 && !numprojid(2000) && !numprojid(2006) && !numprojid(2007)
triggerall = P2bodydist X >= 100
trigger1 = ctrl
trigger2 = stateno = 211 && movecontact = 1
trigger3 = stateno = 241 && movecontact = 1
trigger4 = stateno = 800 && movecontact = 1
trigger5 = stateno = 995 && movecontact = 1
value = IfElse(Random < 500,2000,IfElse(Random < 500,2005,2000))
;----------------------------------------------------------------------------
;medium punch
[State -1, AI hishou nichirinzan]
type = ChangeState
triggerall = var(5) = 1
triggerall = stateno != [3000,3999]
triggerall = var(59) = 1
triggerall = StateType != A
triggerall = random <= 300
triggerall = Movetype != H
triggerall = P2Life > 0
triggerall = P2bodydist X <= 40
triggerall = p2stateno != [150,152]
trigger1 = ctrl
trigger2 = stateno = 211 && movecontact = 1
trigger3 = stateno = 241 && movecontact = 1
trigger4 = stateno = 410 && movecontact = 1
trigger5 = stateno = 400 && movecontact = 1
trigger6 = stateno = 800 && movecontact = 1
value = IfElse(random < 300,1300,IfElse(random < 400,1305,1300))
;----------------------------------------------------------------------------
;medium punch
[State -1, AI shippuken]
type = ChangeState
triggerall = var(5) = 1
triggerall = stateno != [3000,3999]
triggerall = var(59) = 1
triggerall = StateType = A
triggerall = random <= 250
triggerall = Movetype != H
triggerall = P2Life > 0
triggerall = P2bodydist X >= 160
triggerall = p2stateno != [150,152]
trigger1 = ctrl
trigger2 = stateno = 640 && movecontact = 1
value = 1100
;----------------------------------------------------------------------------
;medium punch
[State -1, AI dshippuken]
type = ChangeState
triggerall = var(5) = 2
triggerall = stateno != [3000,3999]
triggerall = var(59) = 1
triggerall = StateType = A
triggerall = random <= 450
triggerall = Movetype != H
triggerall = P2Life > 0
triggerall = P2bodydist X >= 160
triggerall = p2stateno != [150,152]
trigger1 = ctrl = 1
trigger2 = stateno = 640 && movecontact = 1
trigger3 = stateno = 815 && movecontact = 1
value = 2150
;----------------------------------------------------------------------------
;medium punch
[State -1, AI jaeiken]
type = ChangeState
triggerall = var(5) = 1
triggerall = stateno != [3000,3999]
triggerall = var(59) = 1
triggerall = StateType != A
triggerall = Movetype != H
triggerall = P2Life > 0
triggerall = p2stateno != [150,152]
trigger1 = stateno = 211 && movecontact = 1
trigger2 = stateno = 241 && movecontact = 1
trigger3 = stateno = 410 && movecontact = 1
trigger4 = stateno = 800 && movecontact = 1
value = 1200
;----------------------------------------------------------------------------
;medium punch
[State -1, AI njaeiken]
type = ChangeState
triggerall = var(5) = 2
triggerall = stateno != [3000,3999]
triggerall = var(59) = 1
triggerall = StateType != A
triggerall = random <= 100
triggerall = Movetype != H
triggerall = P2Life > 0
triggerall = P2bodydist X <= 120
triggerall = p2stateno != [150,152]
trigger1 = ctrl
trigger2 = stateno = 211 && movecontact = 1
trigger3 = stateno = 241 && movecontact = 1
trigger4 = stateno = 410 && movecontact = 1
trigger5 = stateno = 800 && movecontact = 1
trigger6 = stateno = 995 && movecontact = 1
value = IfElse(random < 300,2200,IfElse(random < 400,2250,2200))
;----------------------------------------------------------------------------
;medium punch
[State -1, AI high counter]
type = ChangeState
triggerall = stateno != [3000,3999]
triggerall = var(59) = 1 && var(28)=0
triggerall = StateType != A
triggerall = random <= 300
triggerall = Movetype != H
triggerall = P2Life > 0
triggerall = inguarddist && enemynear,vel x >= 0 && (enemynear,vel y = [-2,8])
trigger1 = (enemynear,statetype=A) || (enemynear,hitdefattr=A,NA) || (enemynear,hitdefattr=SCA,SA,HA) || (enemynear,stateno=[1000,4999])
trigger1 = ctrl
value = 1400
;----------------------------------------------------------------------------
;medium punch
[State -1, AI mid counter]
type = ChangeState
triggerall = var(5) = 1
triggerall = stateno != [3000,3999]
triggerall = var(59) = 1 && var(28)=0
triggerall = StateType != A
triggerall = random <= 250
triggerall = Movetype != H
triggerall = P2Life > 0
triggerall = P2bodydist X <= 60
trigger1 = (enemynear,hitdefattr=SC,NA) || (enemynear,stateno=[200,400])
trigger1 = ctrl
value = 1410
;----------------------------------------------------------------------------
;medium punch
[State -1, AI low counter]
type = ChangeState
triggerall = stateno != [3000,3999]
triggerall = var(59) = 1 && var(28)=0
triggerall = StateType != A
triggerall = random <= 150
triggerall = Movetype != H
triggerall = P2Life > 0
triggerall = P2bodydist X <= 60
trigger1 = (enemynear,hitdefattr=C,NA)
trigger1 = ctrl
value = 1415
;----------------------------------------------------------------------------
;medium punch
[State -1, AI Nmid counter]
type = ChangeState
triggerall = var(5) = 2
triggerall = stateno != [3000,3999]
triggerall = var(59) = 1 && var(28)=0
triggerall = StateType != A
triggerall = random <= 250
triggerall = Movetype != H
triggerall = P2Life > 0
triggerall = P2bodydist X <= 60
trigger1 = (enemynear,hitdefattr=SC,NA) || (enemynear,stateno=[200,400])
trigger1 = ctrl
value = 1449
;---------------------------------------------------------------------------
;Throw
[State -1, AI Throw]
type = ChangeState
value = 850
triggerall = stateno != [3000,3999]
triggerall = var(59) = 1
triggerall = random <= 150
triggerall = Movetype != H
triggerall = P2Life > 0
triggerall = p2bodydist X < 30 && p2movetype != H
triggerall = stateno != 100 && statetype = S
trigger1 = ctrl
;----------------------------------------------------------------------------
;medium punch
[State -1, AI raging storm]
type = ChangeState
triggerall = var(5)=1
triggerall = stateno != [3000,3999]
triggerall = power >= 1000
triggerall = var(59) = 1
triggerall = StateType != A
triggerall = random <= 200
triggerall = Movetype != H
triggerall = P2bodydist X <= 60
triggerall = p2statetype != L
triggerall = p2stateno != [150,152]
triggerall = P2Life > 0
trigger1 = ctrl
trigger2 = stateno = 211 && movecontact = 1
trigger3 = stateno = 241 && movecontact = 1
trigger4 = stateno = 410 && movecontact = 1
trigger5 = stateno = 400 && movecontact = 1
trigger6 = stateno = 1206 && movecontact = 1 && fvar(5)>=1000
trigger7 = stateno = 800 && movecontact = 1
value = 3000
;----------------------------------------------------------------------------
;medium punch
[State -1, AI raging storm sdm]
type = ChangeState
triggerall = var(5)=1
triggerall = stateno != [3000,3999]
triggerall = power >= 2000
triggerall = var(59) = 1
triggerall = StateType != A
triggerall = random <= 200
triggerall = Movetype != H
triggerall = P2bodydist X <= 60
triggerall = p2statetype != L
triggerall = p2stateno != [150,152]
triggerall = P2Life > 0
trigger1 = ctrl
trigger2 = stateno = 211 && movecontact = 1
trigger3 = stateno = 241 && movecontact = 1
trigger4 = stateno = 410 && movecontact = 1
trigger5 = stateno = 400 && movecontact = 1
trigger6 = stateno = 1206 && movecontact = 1 && fvar(5)>=1000
value = 3010
;----------------------------------------------------------------------------
;medium punch
[State -1, AI rashoumon]
type = ChangeState
triggerall = var(5)=1
triggerall = stateno != [3000,3999]
triggerall = power >= 1000
triggerall = var(59) = 1
triggerall = StateType != A
triggerall = random <= 250
triggerall = Movetype != H
triggerall = P2bodydist X <= 30
triggerall = p2statetype != L
triggerall = p2stateno != [150,152]
triggerall = P2Life > 0
trigger1 = ctrl
trigger2 = stateno = 211 && movecontact = 1
trigger3 = stateno = 241 && movecontact = 1
trigger4 = stateno = 410 && movecontact = 1
trigger5 = stateno = 400 && movecontact = 1
value = 3100
;----------------------------------------------------------------------------
;medium punch
[State -1, AI deadlyrave]
type = ChangeState
triggerall = var(5)=1
triggerall = stateno != [3000,3999]
triggerall = power >= 2000
triggerall = var(59) = 1
triggerall = StateType != A
triggerall = random <= 150
triggerall = Movetype != H
triggerall = P2bodydist X <= 110
triggerall = p2statetype != L
triggerall = p2stateno != [150,152]
triggerall = P2Life > 0
trigger1 = stateno = 211 && movecontact = 1
trigger2 = stateno = 241 && movecontact = 1
trigger3 = stateno = 410 && movecontact = 1
trigger4 = stateno = 400 && movecontact = 1
trigger5 = stateno = 1206 && movecontact = 1 && fvar(5)>=1000
trigger6 = stateno = 800 && movecontact = 1
value = 3200
;----------------------------------------------------------------------------
;medium punch
[State -1, AI nraging storm]
type = ChangeState
triggerall = var(5)=2
triggerall = stateno != [3000,3999]
triggerall = power >= 1000
triggerall = var(59) = 1
triggerall = StateType != A
triggerall = random <= 200
triggerall = Movetype != H
triggerall = P2bodydist X <= 60
triggerall = p2stateno != [150,152]
triggerall = P2Life > 0
trigger1 = ctrl
trigger2 = stateno = 211 && movecontact = 1
trigger3 = stateno = 241 && movecontact = 1
trigger4 = stateno = 410 && movecontact = 1
trigger5 = stateno = 400 && movecontact = 1
trigger6 = stateno = 2205 && movecontact = 1 && fvar(5)>=1000
trigger7 = stateno = 800 && movecontact = 1
trigger8 = stateno = 995 && movecontact = 1
value = 4000
;----------------------------------------------------------------------------
;medium punch
[State -1, AI ndeadlyrave]
type = ChangeState
triggerall = var(5)=2
triggerall = stateno != [3000,3999]
triggerall = power >= 1000
triggerall = var(59) = 1
triggerall = StateType != A
triggerall = random <= 200
triggerall = Movetype != H
triggerall = P2bodydist X <= 160
triggerall = p2stateno != [150,152]
triggerall = P2Life > 0
triggerall = enemynear, pos y = [0,-30]
trigger1 = ctrl
trigger2 = stateno = 211 && movecontact = 1
trigger3 = stateno = 241 && movecontact = 1
trigger4 = stateno = 410 && movecontact = 1
trigger5 = stateno = 400 && movecontact = 1
trigger6 = stateno = 2205 && movecontact = 1 && fvar(5)>=1000
trigger7 = stateno = 800 && movecontact = 1
trigger8 = stateno = 995 && movecontact = 1
value = 4100
;----------------------------------------------------------------------------
;medium punch
[State -1, AI nashurashipp]
type = ChangeState
triggerall = var(5)=2
triggerall = stateno != [3000,3999]
triggerall = power >= 2000
triggerall = var(59) = 1
triggerall = StateType != A
triggerall = random <= 200
triggerall = Movetype != H
triggerall = P2bodydist X <= 60
triggerall = p2stateno != [150,152]
triggerall = P2Life > 0
trigger1 = stateno = 211 && movecontact = 1
trigger2 = stateno = 241 && movecontact = 1
trigger3 = stateno = 410 && movecontact = 1
trigger4 = stateno = 400 && movecontact = 1
trigger5 = stateno = 2205 && movecontact = 1 && fvar(5)>=1000
trigger6 = stateno = 800 && movecontact = 1
trigger7 = stateno = 995 && movecontact = 1
value = 4300
;----------------------------------------------------------------------------
;medium punch
[State -1, AI nragingdeadendactivate]
type = ChangeState
triggerall = var(5)=2&&var(28)=0
triggerall = stateno != [3000,3999]
triggerall = power >= 2000
triggerall = var(59) = 1
triggerall = StateType != A
triggerall = random <= 200
triggerall = Movetype != H
triggerall = P2bodydist X >= 80
triggerall = p2stateno != [150,152]
triggerall = P2Life > 0
trigger1 = ctrl
value = 4400
;----------------------------------------------------------------------------
;medium punch
[State -1, AI nragingdeadcounter]
type = ChangeState
triggerall = var(5)=2&&var(28)>0
triggerall = stateno != [3000,3999]
triggerall = var(59) = 1
triggerall = StateType != A
triggerall = random <= 250
triggerall = Movetype != H
triggerall = P2Life > 0
trigger1 = (enemynear,statetype=A) || (enemynear,hitdefattr=SCA,NA,SA,HA) || (enemynear,stateno=[1000,4999])
trigger1 = ctrl
value = 4402

